# fileName.tcl --
#
#        This file implements a protoType header for packages
#        written in the Tcl scripting language.
#
# Copyright (c) 1997 Sun Microsystems, Inc.
#
# See the file "license.terms" for information on usage and
# redistribution of this file, and for a DISCLAIMER OF ALL WARRANTIES.
#
# SCCS: %Z% %M% %I% %E% %U% 


package require otherPackage 1.0
package provide thisPackage 1.0
namespace eval thisPackage {
    export functionName
}
